@@ -139,18 +139,18 @@ class CodePipelineClient:
         category: Literal["Source", "Build", "Deploy", "Test", "Invoke", "Approval"],
         provider: str,
         version: str,
-        inputArtifactDetails: ArtifactDetailsTypeDef,
-        outputArtifactDetails: ArtifactDetailsTypeDef,
-        settings: ActionTypeSettingsTypeDef = None,
-        configurationProperties: List[ActionConfigurationPropertyTypeDef] = None,
-        tags: List[TagTypeDef] = None,
+        inputArtifactDetails: "ArtifactDetailsTypeDef",
+        outputArtifactDetails: "ArtifactDetailsTypeDef",
+        settings: "ActionTypeSettingsTypeDef" = None,
+        configurationProperties: List["ActionConfigurationPropertyTypeDef"] = None,
+        tags: List["TagTypeDef"] = None,
     ) -> CreateCustomActionTypeOutputTypeDef:
         """
         [Client.create_custom_action_type documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codepipeline.html#CodePipeline.Client.create_custom_action_type)
         """
 
     def create_pipeline(
-        self, pipeline: PipelineDeclarationTypeDef, tags: List[TagTypeDef] = None
+        self, pipeline: "PipelineDeclarationTypeDef", tags: List["TagTypeDef"] = None
     ) -> CreatePipelineOutputTypeDef:
         """
         [Client.create_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codepipeline.html#CodePipeline.Client.create_pipeline)
@@ -287,7 +287,7 @@ class CodePipelineClient:
 
     def poll_for_jobs(
         self,
-        actionTypeId: ActionTypeIdTypeDef,
+        actionTypeId: "ActionTypeIdTypeDef",
         maxBatchSize: int = None,
         queryParam: Dict[str, str] = None,
     ) -> PollForJobsOutputTypeDef:
@@ -296,7 +296,7 @@ class CodePipelineClient:
         """
 
     def poll_for_third_party_jobs(
-        self, actionTypeId: ActionTypeIdTypeDef, maxBatchSize: int = None
+        self, actionTypeId: "ActionTypeIdTypeDef", maxBatchSize: int = None
     ) -> PollForThirdPartyJobsOutputTypeDef:
         """
         [Client.poll_for_third_party_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codepipeline.html#CodePipeline.Client.poll_for_third_party_jobs)
@@ -307,7 +307,7 @@ class CodePipelineClient:
         pipelineName: str,
         stageName: str,
         actionName: str,
-        actionRevision: ActionRevisionTypeDef,
+        actionRevision: "ActionRevisionTypeDef",
     ) -> PutActionRevisionOutputTypeDef:
         """
         [Client.put_action_revision documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codepipeline.html#CodePipeline.Client.put_action_revision)
@@ -362,7 +362,7 @@ class CodePipelineClient:
         """
 
     def put_webhook(
-        self, webhook: WebhookDefinitionTypeDef, tags: List[TagTypeDef] = None
+        self, webhook: "WebhookDefinitionTypeDef", tags: List["TagTypeDef"] = None
     ) -> PutWebhookOutputTypeDef:
         """
         [Client.put_webhook documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codepipeline.html#CodePipeline.Client.put_webhook)
@@ -398,7 +398,7 @@ class CodePipelineClient:
         [Client.stop_pipeline_execution documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codepipeline.html#CodePipeline.Client.stop_pipeline_execution)
         """
 
-    def tag_resource(self, resourceArn: str, tags: List[TagTypeDef]) -> Dict[str, Any]:
+    def tag_resource(self, resourceArn: str, tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
         [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codepipeline.html#CodePipeline.Client.tag_resource)
         """
@@ -408,7 +408,9 @@ class CodePipelineClient:
         [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codepipeline.html#CodePipeline.Client.untag_resource)
         """
 
-    def update_pipeline(self, pipeline: PipelineDeclarationTypeDef) -> UpdatePipelineOutputTypeDef:
+    def update_pipeline(
+        self, pipeline: "PipelineDeclarationTypeDef"
+    ) -> UpdatePipelineOutputTypeDef:
         """
         [Client.update_pipeline documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.24/reference/services/codepipeline.html#CodePipeline.Client.update_pipeline)
         """
